=========================================
 :mod:`xoeuf.tools` -- Various utilities
=========================================

.. automodule:: xoeuf.tools
   :members: normalize_datestr, normalize_datetimestr, parse_datetime,
	     parse_date, normalize_date, normalize_datetime, add_symbols_to_xmls,
	     localtime_as_remotetime, get_time_from_float, get_time_string,
	     get_time_string_from_float
